package com.ruoyi.szxc.service;

import java.util.List;
import com.ruoyi.szxc.domain.SzxcTaskRecard;

/**
 * 任务处理记录Service接口
 * 
 * @author hs
 * @date 2024-04-28
 */
public interface ISzxcTaskRecardService 
{
    /**
     * 查询任务处理记录
     * 
     * @param id 任务处理记录主键
     * @return 任务处理记录
     */
    public SzxcTaskRecard selectSzxcTaskRecardById(Long id);

    /**
     * 查询任务处理记录列表
     * 
     * @param szxcTaskRecard 任务处理记录
     * @return 任务处理记录集合
     */
    public List<SzxcTaskRecard> selectSzxcTaskRecardList(SzxcTaskRecard szxcTaskRecard);

    /**
     * 新增任务处理记录
     * 
     * @param szxcTaskRecard 任务处理记录
     * @return 结果
     */
    public int insertSzxcTaskRecard(SzxcTaskRecard szxcTaskRecard);

    /**
     * 修改任务处理记录
     * 
     * @param szxcTaskRecard 任务处理记录
     * @return 结果
     */
    public int updateSzxcTaskRecard(SzxcTaskRecard szxcTaskRecard);

    /**
     * 批量删除任务处理记录
     * 
     * @param ids 需要删除的任务处理记录主键集合
     * @return 结果
     */
    public int deleteSzxcTaskRecardByIds(Long[] ids);

    /**
     * 删除任务处理记录信息
     * 
     * @param id 任务处理记录主键
     * @return 结果
     */
    public int deleteSzxcTaskRecardById(Long id);
}
