package com.ruoyi.szxc.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.szxc.domain.SzxcTaskRecard;
import com.ruoyi.szxc.service.ISzxcTaskRecardService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 任务处理记录Controller
 * 
 * @author hs
 * @date 2024-04-28
 */
@RestController
@RequestMapping("/szxc/taskRecard")
public class SzxcTaskRecardController extends BaseController
{
    @Autowired
    private ISzxcTaskRecardService szxcTaskRecardService;

    /**
     * 查询任务处理记录列表
     */
    @PreAuthorize("@ss.hasPermi('szxc:taskRecard:list')")
    @GetMapping("/list")
    public TableDataInfo list(SzxcTaskRecard szxcTaskRecard)
    {
        startPage();
        List<SzxcTaskRecard> list = szxcTaskRecardService.selectSzxcTaskRecardList(szxcTaskRecard);
        return getDataTable(list);
    }

    /**
     * 导出任务处理记录列表
     */
    @PreAuthorize("@ss.hasPermi('szxc:taskRecard:export')")
    @Log(title = "任务处理记录", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, SzxcTaskRecard szxcTaskRecard)
    {
        List<SzxcTaskRecard> list = szxcTaskRecardService.selectSzxcTaskRecardList(szxcTaskRecard);
        ExcelUtil<SzxcTaskRecard> util = new ExcelUtil<SzxcTaskRecard>(SzxcTaskRecard.class);
        util.exportExcel(response, list, "任务处理记录数据");
    }

    /**
     * 获取任务处理记录详细信息
     */
    @PreAuthorize("@ss.hasPermi('szxc:taskRecard:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(szxcTaskRecardService.selectSzxcTaskRecardById(id));
    }

    /**
     * 新增任务处理记录
     */
    @PreAuthorize("@ss.hasPermi('szxc:taskRecard:add')")
    @Log(title = "任务处理记录", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody SzxcTaskRecard szxcTaskRecard)
    {
        return toAjax(szxcTaskRecardService.insertSzxcTaskRecard(szxcTaskRecard));
    }

    /**
     * 修改任务处理记录
     */
    @PreAuthorize("@ss.hasPermi('szxc:taskRecard:edit')")
    @Log(title = "任务处理记录", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody SzxcTaskRecard szxcTaskRecard)
    {
        return toAjax(szxcTaskRecardService.updateSzxcTaskRecard(szxcTaskRecard));
    }

    /**
     * 删除任务处理记录
     */
    @PreAuthorize("@ss.hasPermi('szxc:taskRecard:remove')")
    @Log(title = "任务处理记录", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(szxcTaskRecardService.deleteSzxcTaskRecardByIds(ids));
    }
}
